@@ -1,2 +1,2 @@
-from bolinette.abc.inject import Injection
 from bolinette.abc.context import Context, WithContext
+import bolinette.abc.inject as inject
