@@ -1,6 +1,6 @@
 from bolinette.blnt.logging import Logger
 from bolinette.blnt.props import Properties
-from bolinette.blnt.inject import InstantiableAttribute, BolinetteInjection, InjectionCollection, InjectionProxy
+from bolinette.blnt.inject import InstantiableAttribute, BolinetteInjection, InjectionProxy
 from bolinette.blnt.cache import cache, InitFunc
 from bolinette.blnt.environment import init, Environment
 from bolinette.blnt.jwt import JWT
