@@ -1,15 +1,15 @@
 from aiohttp import web as aio_web
 
-from bolinette import web, blnt
-from bolinette.decorators import controller, get, injected
+from bolinette import abc, web
+from bolinette.decorators import controller, get
 from bolinette.defaults.services import FileService
 
 
 @controller('file', '/file', middlewares=['auth'])
 class FileController(web.Controller):
-    @injected
-    def file_service(self, inject: 'blnt.BolinetteInjection') -> FileService:
-        return inject.services.require('file')
+    def __init__(self, context: abc.Context, file_service: FileService):
+        super().__init__(context)
+        self.file_service = file_service
 
     def default_routes(self):
         return [
