@@ -1,13 +1,13 @@
-from bolinette import web, blnt
-from bolinette.decorators import controller, get, injected
+from bolinette import abc, web
+from bolinette.decorators import controller, get
 from bolinette.defaults.services import TimezoneService
 
 
 @controller('tz', '/tz')
 class TimezoneController(web.Controller):
-    @injected
-    def tz_service(self, inject: 'blnt.BolinetteInjection') -> TimezoneService:
-        return inject.services.require('tz')
+    def __init__(self, context: abc.Context, tz_service: TimezoneService):
+        super().__init__(context)
+        self.tz_service = tz_service
 
     @get('')
     async def all_timezones(self):
