@@ -5,7 +5,7 @@ from bolinette.decorators import model
 @model('file')
 class File(core.Model):
     id = types.defs.Column(types.db.Integer, primary_key=True)
-    key = types.defs.Column(types.db.String, nullable=False, unique=True, model_id=True)
+    key = types.defs.Column(types.db.String, nullable=False, unique=True, entity_key=True)
     name = types.defs.Column(types.db.String, nullable=False)
     mime = types.defs.Column(types.db.String, nullable=False)
 
