@@ -1,3 +1,3 @@
 from bolinette.testing.mock import Mock, Mocked
-from bolinette.testing.client import TestClient
+from bolinette.testing.client import BolitestClient
 from bolinette.testing.decorator import bolitest
