@@ -5,6 +5,7 @@ from typing import Any
 from aiohttp.web_request import Request
 
 from bolinette import abc, blnt, core, web
+from bolinette.blnt.inject import instantiate_type
 from bolinette.decorators import injected
 from bolinette.exceptions import InitError
 from bolinette.utils import functions
@@ -13,7 +14,7 @@ from bolinette.utils import functions
 class Controller(abc.WithContext):
     __blnt__: 'ControllerMetadata' = None
 
-    def __init__(self, context: 'blnt.BolinetteContext'):
+    def __init__(self, context: abc.Context):
         super().__init__(context)
         self.__props__ = ControllerProps(self)
         self.response = web.Response(context)
@@ -21,8 +22,8 @@ class Controller(abc.WithContext):
             self.defaults = ControllerDefaults(self)
 
     @injected
-    def service(self, inject: 'blnt.BolinetteInjection') -> 'core.Service':
-        return inject.services.require(self.__blnt__.service_name)
+    def service(self, inject: abc.inject.Injection) -> 'core.Service':
+        return inject.require('service', self.__blnt__.service_name)
 
     def default_routes(self) -> list['web.ControllerRoute']:
         return []
@@ -50,7 +51,7 @@ class ControllerProps(blnt.Properties):
         return self._get_attributes_of_type(self.parent, ControllerRoute)
 
 
-class ControllerRoute:
+class ControllerRoute(abc.inject.Instantiable):
     def __init__(self, controller: 'web.Controller', func: Callable, path: str, method: web.HttpMethod,
                  docstring: str | None, expects: 'Expects' = None, returns: 'Returns' = None,
                  inner_route: 'ControllerRoute' = None, middlewares: list[str] = None):
@@ -123,7 +124,7 @@ class ControllerRoute:
             middleware = find[0]
             middleware.options = {}
         else:
-            middleware = blnt.cache.middlewares[name](context)
+            middleware = instantiate_type(context, blnt.cache.middlewares[name])
 
         if not middleware.__blnt__.loadable and not system:
             raise InitError(f'[{type(self.controller).__name__}] Middleware '
@@ -189,12 +190,12 @@ class ControllerDefaults(abc.WithContext):
         self.controller = controller
 
     @injected
-    def service(self, inject: 'blnt.BolinetteInjection') -> 'core.Service':
-        return inject.services.require(self.controller.__blnt__.service_name)
+    def service(self, inject: abc.inject.Injection):
+        return inject.require('service', self.controller.__blnt__.service_name)
 
     def _get_url_keys(self, key: str | list[str] | None, *, route: str) -> list[str]:
         if key is None:
-            entity_key = self.service.repo.model.__props__.entity_key
+            entity_key = self.service.model.__props__.entity_key
             if entity_key is None:
                 raise InitError(f'Default route "{route}" for controller "{self.service.repo.model.__blnt__.name}" '
                                 f'must define a key or set entity_key=True in one or more columns in the model')
