@@ -1,18 +1,17 @@
 import re
-from collections.abc import Generator
-from typing import Any
+from collections.abc import Iterator
 
 from aiohttp import web as aio_web
 
-from bolinette import blnt
+from bolinette import abc, blnt
 from bolinette.blnt import Properties
 
 
-class Topic:
+class Topic(abc.WithContext):
     __blnt__: 'TopicMetadata' = None
 
     def __init__(self, context: 'blnt.BolinetteContext'):
-        self.context = context
+        super().__init__(context)
         self.__props__ = TopicProps(self)
         self._subscriptions: dict[str, list[aio_web.WebSocketResponse]] = {}
 
@@ -55,7 +54,7 @@ class TopicProps(Properties):
     def __init__(self, topic: Topic):
         super().__init__(topic)
 
-    def get_channels(self) -> Generator[tuple[str, 'TopicChannel'], Any, None]:
+    def get_channels(self) -> Iterator[tuple[str, 'TopicChannel']]:
         return self._get_cls_attributes_of_type(type(self.parent), TopicChannel)
 
 
